@@ -93,11 +93,25 @@ class BaseModelAdmin(BaseView):
     def allow_pk(self):
         return not self.model._meta.auto_increment
 
+    def get_column(self, instance, name):
+        parts = name.split('.')
+        obj = instance
+        for p in parts:
+            obj = getattr(obj, p, None)
+            if not obj:
+                break
+        return self.get_column_value(obj)
+
     def get_column_value(self, value):
         if callable(value):
             return value()
         return value
 
+    def get_reference(self, column_value):
+        for model, model_view in self.admin._models:
+            if type(column_value) == model:
+                return '/admin/%s/%s/' % (model_view.endpoint, column_value.pk)
+
     def get_converter(self):
         raise NotImplemented()
 
@@ -185,8 +199,8 @@ class BaseModelAdmin(BaseView):
                     return self.dispatch_save_redirect(instance)
                 except Exception, ex:
                     print traceback.format_exc()
-                    # if self.session:
-                    #     self.session.rollback()
+                    if self.session:
+                        self.session.rollback()
                     flash(gettext('Failed to add model. %(error)s',
                           error=str(ex)), 'error')
 
@@ -246,8 +260,9 @@ class BaseModelAdmin(BaseView):
         sort, sort_desc = self.sort
         page = self.page
         search_query = self.search
-        count, data = self.get_list(page=page, sort=sort, sort_desc=sort_desc, search_query=search_query)
-        sort, sort_desc = self.sort
+        count, data = self.get_list(page=page, sort=sort, sort_desc=sort_desc,
+                                    search_query=search_query)
+
         return self.render(self.list_template, data=data, page=page,
                            total_pages=self.total_pages(count), sort=sort,
                            sort_desc=sort_desc, count=count, modeladmin=self,
@@ -257,7 +272,7 @@ class BaseModelAdmin(BaseView):
     def edit(self, pk):
         try:
             instance = self.get_object(pk)
-        except self.DoesNotExist:
+        except self.model.DoesNotExist:
             abort(404)
 
         Form = self.get_form(include_readonly=request.method == 'GET')
